==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Your_Account/language/lang-arabic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL"," ");
define("_YES","");
define("_NO","");
define("_OPTIONAL","()");
define("_REQUIRED","()");
define("_SAVECHANGES"," ");
define("_THRESHOLD","Threshold");
define("_NOCOMMENTS","  ");
define("_NESTED","");
define("_FLAT","");
define("_THREAD"," ");
define("_OLDEST"," ");
define("_NEWEST"," ");
define("_HIGHEST","  ");
define("_ERRORINVEMAIL",":    ");
define("_ERROREMAILSPACES",":      ");
define("_ERRORINVNICK",":    ");
define("_NICK2LONG","  .      25 ");
define("_NAMERESERVED",":     ");
define("_NICKNOSPACES",":      ");
define("_NICKTAKEN",":     ");
define("_EMAILREGISTERED",":     ");
define("_UUSERNAME"," ");
define("_FINISH","");
define("_YOUUSEDEMAIL","       ");
define("_TOREGISTER"," ");
define("_FOLLOWINGMEM","   :");
define("_UNICKNAME","-:");
define("_UPASSWORD","- :");
define("_USERPASS4","  ");
define("_YOUAREREGISTERED","  .          .");
define("_THISISYOURPAGE","  ");
define("_AVATAR","");
define("_WEBSITE","");
define("_ICQ","   ");
define("_AIM","   ");
define("_YIM","  ");
define("_MSNM","  ");
define("_LOCATION","");
define("_OCCUPATION","");
define("_INTERESTS","");
define("_SIGNATURE","");
define("_MYHOMEPAGE"," :");
define("_MYEMAIL"," :");
define("_EXTRAINFO"," ");
define("_NOINFOFOR","   ");
define("_LAST10COMMENTS","   ");
define("_LAST10SUBMISSIONS","   ");
define("_LOGININCOR","      ...");
define("_USERLOGIN"," ");
define("_USERREGLOGIN","/ ");
define("_REGNEWUSER","  ");
define("_LIST","");
define("_NEWUSER"," ");
define("_PASSWILLSEND","(       )");
define("_COOKIEWARNING",":     .");
define("_ASREGUSER","     :");
define("_ASREG1","  ");
define("_ASREG2","  ");
define("_ASREG3","         ");
define("_ASREG4","       ");
define("_ASREG5","  ");
define("_ASREG6","  ");
define("_ASREG7","  ...");
define("_REGISTERNOW"," !  !");
define("_WEDONTGIVE","    .");
define("_ALLOWEMAILVIEW","      ");
define("_OPTION","");
define("_PASSWORDLOST","   ѿ");
define("_NOPROBLEM"," .        .             .                 .");
define("_CONFIRMATIONCODE"," ");
define("_SENDPASSWORD","  ");
define("_YOUARELOGGEDOUT","  !");
define("_SORRYNOUSERINFO","ǡ      ");
define("_USERACCOUNT"," ");
define("_AT","");
define("_HASTHISEMAIL","    .");
define("_AWEBUSERFROM","  ");
define("_HASREQUESTED","   .");
define("_YOURNEWPASSWORD","   :");
define("_YOUCANCHANGE","     ");
define("_IFYOUDIDNOTASK","     .       .");
define("_UPDATEFAILED","    .   .");
define("_PASSWORD4","  ");
define("_MAILED",".");
define("_CODEREQUESTED","     .");
define("_YOURCODEIS","  :");
define("_WITHTHISCODE","      ");
define("_IFYOUDIDNOTASK2","      ...     .");
define("_CODEFOR","  ");
define("_USERPASSWORD4","  ");
define("_UREALNAME"," ");
define("_UREALEMAIL"," ");
define("_EMAILNOTPUBLIC","(             )");
define("_UFAKEMAIL","  ");
define("_EMAILPUBLIC","(   .  )");
define("_YOURHOMEPAGE","");
define("_YOURAVATAR"," ");
define("_YICQ","   ");
define("_YAIM","   ");
define("_YYIM"," ");
define("_YMSNM"," ");
define("_YLOCATION","");
define("_YOCCUPATION","");
define("_YINTERESTS","");
define("_255CHARMAX","(  255 .      )");
define("_CANKNOWABOUT","(  255 .      )");
define("_TYPENEWPASSWORD","(    )");
define("_SOMETHINGWRONG","   ...?");
define("_PASSDIFFERENT","    .    .");
define("_CHARLONG","");
define("_AVAILABLEAVATARS","  ");
define("_NEWSINHOME","     ");
define("_MAX127","(  127):");
define("_ACTIVATEPERSONAL","  ");
define("_CHECKTHISOPTION","(         )");
define("_YOUCANUSEHTML","(     )");
define("_SELECTTHEME","  ");
define("_THEMETEXT1","     .");
define("_THEMETEXT2","    .");
define("_THEMETEXT3","     .");
define("_DISPLAYMODE"," ");
define("_SORTORDER"," ");
define("_COMMENTSWILLIGNORED","      .");
define("_UNCUT","Uncut and Raw");
define("_EVERYTHING","Almost Everything");
define("_FILTERMOSTANON","Filter Most Anonymous");
define("_USCORE","");
define("_SCORENOTE","    ,    .     .");
define("_NOSCORES","  ");
define("_HIDDESCORES","( :      .)");
define("_MAXCOMMENT","Max Comment Length");
define("_TRUNCATES","(         .     )");
define("_BYTESNOTE"," (1024  = 1)");
define("_USENDPRIVATEMSG","  ");
define("_THEMESELECTION","  ");
define("_COMMENTSCONFIG"," ");
define("_HOMECONFIG","  ");
define("_PERSONALINFO"," ");
define("_USERSTATUS"," ");
define("_ONLINE","Online");
define("_OFFLINE","Offline");
define("_CHANGEYOURINFO"," ");
define("_CONFIGCOMMENTS","  ");
define("_CHANGEHOME","  ");
define("_LOGOUTEXIT","");
define("_SELECTTHETHEME","  ");
define("_PRIVATEMESSAGES"," ");
define("_EDITUSER"," ");
define("_RECEIVENEWSLETTER","Receive Newsletter by Email?");
define("_NOTSUBSCRIBED","You're not subscribed to our Newsletter");
define("_SUBSCRIBED","You're subscribed to our Newsletter");
define("_USERCHECKDATA","please check the following information. If all is correct you can proceed with the registration by clicking on \"Finish\" button, otherwise \"Go Back\" and change whatever information is needed.");
define("_USERFINALSTEP","New User Registration: Final Step");
define("_ACCOUNTCREATED","New User Account Created!");
define("_THANKSUSER","Thank you for registering at");
define("_YOUCANLOGIN","In a few seconds you'll receive an email from our system with your assigned password. Then you can login <a href=\"modules.php?name=Your_Account\">here</a>. Remember to change you password and to configure your account preferences. Hope you can enjoy our services.");
define("_BROWSEUSERS","Browse Users");
define("_SEARCHUSERS","Search Users");

?>

==> phpnuke-6.0.tgz: www/phpnuke/html/modules/Your_Account/language/lang-arabic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL"," ");
define("_YES","");
define("_NO","");
define("_OPTIONAL","()");
define("_REQUIRED","()");
define("_SAVECHANGES"," ");
define("_THRESHOLD","Threshold");
define("_NOCOMMENTS","  ");
define("_NESTED","");
define("_FLAT","");
define("_THREAD"," ");
define("_OLDEST"," ");
define("_NEWEST"," ");
define("_HIGHEST","  ");
define("_ERRORINVEMAIL",":    ");
define("_ERROREMAILSPACES",":      ");
define("_ERRORINVNICK",":    ");
define("_NICK2LONG","  .      25 ");
define("_NAMERESERVED",":     ");
define("_NICKNOSPACES",":      ");
define("_NICKTAKEN",":     ");
define("_EMAILREGISTERED",":     ");
define("_UUSERNAME"," ");
define("_FINISH","");
define("_YOUUSEDEMAIL","       ");
define("_TOREGISTER"," ");
define("_FOLLOWINGMEM","   :");
define("_UNICKNAME","-:");
define("_UPASSWORD","- :");
define("_USERPASS4","  ");
define("_YOUAREREGISTERED","  .          .");
define("_THISISYOURPAGE","  ");
define("_AVATAR","");
define("_WEBSITE","");
define("_ICQ","   ");
define("_AIM","   ");
define("_YIM","  ");
define("_MSNM","  ");
define("_LOCATION","");
define("_OCCUPATION","");
define("_INTERESTS","");
define("_SIGNATURE","");
define("_MYHOMEPAGE"," :");
define("_MYEMAIL"," :");
define("_EXTRAINFO"," ");
define("_NOINFOFOR","   ");
define("_LAST10COMMENTS","   ");
define("_LAST10SUBMISSIONS","   ");
define("_LOGININCOR","      ...");
define("_USERLOGIN"," ");
define("_USERREGLOGIN","/ ");
define("_REGNEWUSER","  ");
define("_LIST","");
define("_NEWUSER"," ");
define("_PASSWILLSEND","(       )");
define("_COOKIEWARNING",":     .");
define("_ASREGUSER","     :");
define("_ASREG1","  ");
define("_ASREG2","  ");
define("_ASREG3","         ");
define("_ASREG4","       ");
define("_ASREG5","  ");
define("_ASREG6","  ");
define("_ASREG7","  ...");
define("_REGISTERNOW"," !  !");
define("_WEDONTGIVE","    .");
define("_ALLOWEMAILVIEW","      ");
define("_OPTION","");
define("_PASSWORDLOST","   ѿ");
define("_NOPROBLEM"," .        .             .                 .");
define("_CONFIRMATIONCODE"," ");
define("_SENDPASSWORD","  ");
define("_YOUARELOGGEDOUT","  !");
define("_SORRYNOUSERINFO","ǡ      ");
define("_USERACCOUNT"," ");
define("_AT","");
define("_HASTHISEMAIL","    .");
define("_AWEBUSERFROM","  ");
define("_HASREQUESTED","   .");
define("_YOURNEWPASSWORD","   :");
define("_YOUCANCHANGE","     ");
define("_IFYOUDIDNOTASK","     .       .");
define("_UPDATEFAILED","    .   .");
define("_PASSWORD4","  ");
define("_MAILED",".");
define("_CODEREQUESTED","     .");
define("_YOURCODEIS","  :");
define("_WITHTHISCODE","      ");
define("_IFYOUDIDNOTASK2","      ...     .");
define("_CODEFOR","  ");
define("_USERPASSWORD4","  ");
define("_UREALNAME"," ");
define("_UREALEMAIL"," ");
define("_EMAILNOTPUBLIC","(             )");
define("_UFAKEMAIL","  ");
define("_EMAILPUBLIC","(   .  )");
define("_YOURHOMEPAGE","");
define("_YOURAVATAR"," ");
define("_YICQ","   ");
define("_YAIM","   ");
define("_YYIM"," ");
define("_YMSNM"," ");
define("_YLOCATION","");
define("_YOCCUPATION","");
define("_YINTERESTS","");
define("_255CHARMAX","(  255 .      )");
define("_CANKNOWABOUT","(  255 .      )");
define("_TYPENEWPASSWORD","(    )");
define("_SOMETHINGWRONG","   ...?");
define("_PASSDIFFERENT","    .    .");
define("_CHARLONG","");
define("_AVAILABLEAVATARS","  ");
define("_NEWSINHOME","     ");
define("_MAX127","(  127):");
define("_ACTIVATEPERSONAL","  ");
define("_CHECKTHISOPTION","(         )");
define("_YOUCANUSEHTML","(     )");
define("_SELECTTHEME","  ");
define("_THEMETEXT1","     .");
define("_THEMETEXT2","    .");
define("_THEMETEXT3","     .");
define("_DISPLAYMODE"," ");
define("_SORTORDER"," ");
define("_COMMENTSWILLIGNORED","      .");
define("_UNCUT","Uncut and Raw");
define("_EVERYTHING","Almost Everything");
define("_FILTERMOSTANON","Filter Most Anonymous");
define("_USCORE","");
define("_SCORENOTE","    ,    .     .");
define("_NOSCORES","  ");
define("_HIDDESCORES","( :      .)");
define("_MAXCOMMENT","Max Comment Length");
define("_TRUNCATES","(         .     )");
define("_BYTESNOTE"," (1024  = 1)");
define("_USENDPRIVATEMSG","  ");
define("_THEMESELECTION","  ");
define("_COMMENTSCONFIG"," ");
define("_HOMECONFIG","  ");
define("_PERSONALINFO"," ");
define("_USERSTATUS"," ");
define("_ONLINE","Online");
define("_OFFLINE","Offline");
define("_CHANGEYOURINFO"," ");
define("_CONFIGCOMMENTS","  ");
define("_CHANGEHOME","  ");
define("_LOGOUTEXIT","");
define("_SELECTTHETHEME","  ");
define("_PRIVATEMESSAGES"," ");
define("_EDITUSER"," ");
define("_RECEIVENEWSLETTER","     ɿ");
define("_NOTSUBSCRIBED","     .");
define("_SUBSCRIBED","    .");
define("_USERCHECKDATA","    .           \"\" ,     \"\"   .");
define("_USERFINALSTEP"," :  ");
define("_ACCOUNTCREATED","  !");
define("_THANKSUSER","   ");
define("_YOUCANLOGIN","        .      <a href=\"modules.php?name=Your_Account\"></a>.           .     .");
define("_BROWSEUSERS"," ");
define("_SEARCHUSERS","  ");
define("_BROADCAST","  ");
define("_BROADCASTTEXT","  <i> </i>   (255   ).          .            .            <a href=\"modules.php?name=Your_Account&amp;op=edithome\"></a>.         .");
define("_SEND","");
define("_MESSAGEACTIVATE","   ɿ");
define("_BROADCASTSENT","   .");
define("_BROADCASTNOTSENT","<b>:</b>         .       10 .");
define("_RETURNPAGE","   ");
define("_MYHEADLINES","   ");
define("_SELECTASITE","      :");
define("_SELECTASITE2"," ");
define("_ORTYPEURL","    RSS/XML  :");
define("_GO","");
define("_HEADLINESFROM","  ");
define("_WEBMAIL", "");
define("_MESSAGES","");
define("_RETURNACCOUNT", "   ");
define("_ACCESSTO", " ");
define("_CREATEJOURNAL", "  ");
define("_READHEADLINES", "  ");

?>
